@@ -9,7 +9,7 @@ with qw/ PayProp::API::Public::Client::Role::Attribute::Domain /;
 with qw/ PayProp::API::Public::Client::Role::Attribute::Authorization /;
 
 # ABSTRACT: PayProp API Public Client
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has export => (
 	is => 'ro',
@@ -53,7 +53,7 @@ __END__
 
 =head1 NAME
 
-	PayProp::API::Public::Client - PayProp API client.
+PayProp::API::Public::Client - PayProp API client.
 
 =head1 SYNOPSIS
 
@@ -80,8 +80,6 @@ __END__
 		->then( sub {
 			my ( \@beneficiaries ) = @_;
 			...;
-
-			See L<PayProp::API::Public::Client::Response::Export::Beneficiary>
 		} )
 		->wait
 	;
@@ -121,8 +119,6 @@ __END__
 		->then( sub {
 			my ( \@beneficiaries ) = @_;
 			...;
-
-			See L<PayProp::API::Public::Client::Response::Export::Beneficiary>
 		} )
 		->wait
 	;
@@ -130,51 +126,66 @@ __END__
 
 =head1 DESCRIPTION
 
-	The PayProp API Public Module is a standalone module that will allow you to interact with the PayProp API,
-	through a normalised interface. This interface abstracts authentication methods, request and response building and more.
+The PayProp API Public Module is a standalone module that will allow you to interact with the PayProp API,
+through a normalised interface. This interface abstracts authentication methods, request and response building and more.
 
-	This module B<should> be used to access various API requests as defined in C<PayProp::API::Public::Client::Request::*>.
+This module B<should> be used to access various API requests as defined in C<PayProp::API::Public::Client::Request::*>.
 
 =head1 ATTRIBUTES
 
-	C<PayProp::API::Public::Client> implements the following attributes.
+C<PayProp::API::Public::Client> implements the following attributes.
 
 =head2 export
 
 	my $Export = $Client->export;
 	my $beneficiaries_export = $Export->beneficiaries;
 
-	See L<PayProp::API::Public::Client::Request::Export> for available attributes.
+See L<PayProp::API::Public::Client::Request::Export> for available attributes.
 
 =head2 entity
 
 	my $Entity = $Client->entity;
 	my $payment_entity = $Entity->payment;
 
-	See L<PayProp::API::Public::Client::Request::Entity> for available attributes.
+See L<PayProp::API::Public::Client::Request::Entity> for available attributes.
 
-=head1 METHODS
+=head1 ATTRIBUTES
 
+C<PayProp::API::Public::Client> implements the following attributes.
+
+=head2 export
+
+	my $Export = $Client->export;
+	my $beneficiaries_export = $Export->beneficiaries;
+
+See L<PayProp::API::Public::Client::Request::Export> for available attributes.
+
+=head2 entity
+
+	my $Entity = $Client->entity;
+	my $payment_entity = $Entity->payment;
+
+See L<PayProp::API::Public::Client::Request::Entity> for available attributes.
 
 =head1 AUTHOR
 
-	Yanga Kandeni E<lt>yangak@cpan.orgE<gt>
+Yanga Kandeni E<lt>yangak@cpan.orgE<gt>
 
-	Valters Skrupskis E<lt>malishew@cpan.orgE<gt>
+Valters Skrupskis E<lt>malishew@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-	Copyright 2023- PayProp
+Copyright 2023- PayProp
 
 =head1 LICENSE
 
-	This library is free software; you can redistribute it and/or modify
-	it under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
-	If you would like to contribute documentation
-	or file a bug report then please raise an issue / pull request:
+If you would like to contribute documentation
+or file a bug report then please raise an issue / pull request:
 
-	L<https://github.com/Humanstate/api-client-public-module>
+L<https://github.com/Humanstate/api-client-public-module>
 
 =cut
 
