@@ -155,7 +155,7 @@ __END__
 
 =head1 NAME
 
-	PayProp::API::Public::Client::Request::Export::Tenants - Tenant export module.
+PayProp::API::Public::Client::Request::Export::Tenants - Tenant export module.
 
 =head1 SYNOPSIS
 
@@ -175,32 +175,32 @@ __END__
 
 =head1 DESCRIPTION
 
-	Implementation for retrieving tenant export results via API.
-	This module is intended to be accessed via instance of C<PayProp::API::Public::Client>.
+Implementation for retrieving tenant export results via API.
+This module is intended to be accessed via instance of C<PayProp::API::Public::Client>.
 
 =head1 ATTRIBUTES
 
-	C<PayProp::API::Public::Client::Request::Export::Tenants> implements the following attributes.
+C<PayProp::API::Public::Client::Request::Export::Tenants> implements the following attributes.
 
 =head2 url
 
-	An abstraction of the API endpoint receiving the request(s). It is dependant on the API_DOMAIN.com given.
+An abstraction of the API endpoint receiving the request(s). It is dependant on the API_DOMAIN.com given.
 
 =head1 METHODS
 
 =head2 list_p(\%query_params)
 
-	Issues a C<HTTP GET> request to PayProp API C</export/tenants> endpoint. It takes an optional C<HASHREF> of query parameters.
+Issues a C<HTTP GET> request to PayProp API C</export/tenants> endpoint. It takes an optional C<HASHREF> of query parameters.
 
-	See L</"QUERY PARAMETERS"> for a list of available parameters.
+See L</"QUERY PARAMETERS"> for a list of available parameters.
 
 
 =head1 QUERY PARAMETERS
 
 =head2 rows
 
-	B<integer>
-	Restrict rows returned.
+B<integer>
+Restrict rows returned.
 
 	$tenants_export
 		->list_p({ rows => 1 })
@@ -215,8 +215,8 @@ __END__
 
 =head2 page
 
-	B<integer>
-	Return given page number.
+B<integer>
+Return given page number.
 
 	$tenants_export
 		->list_p({ page => 1 })
@@ -231,10 +231,10 @@ __END__
 
 =head2 search_by
 
-	B<Array of string>
-	Items Enum: C<business_name>, C<first_name>, C<last_name>, C<email_address>
+B<Array of string>
+Items Enum: C<business_name>, C<first_name>, C<last_name>, C<email_address>
 
-	To be used with L</"search_value">.
+To be used with L</"search_value">.
 
 	$tenants_export
 		->list_p(
@@ -254,8 +254,8 @@ __END__
 
 =head2 search_value
 
-	B<string> C<[3..50] characters>
-	To be used with L</"search_by">.
+B<string> C<[3..50] characters>
+To be used with L</"search_by">.
 
 	$tenants_export
 		->list_p(
@@ -275,8 +275,8 @@ __END__
 
 =head2 external_id
 
-	B<string> C<<= 32 characters>
-	External ID of tenant.
+B<string> C<E<lt>= 32 characters>
+External ID of tenant.
 
 	$tenants_export
 		->list_p({ external_id => 'ABCD1234' })
@@ -291,8 +291,8 @@ __END__
 
 =head2 property_id
 
-	B<string> C<<= 50 characters>
-	External ID of property.
+B<string> C<E<lt>= 50 characters>
+External ID of property.
 
 	$tenants_export
 		->list_p({ property_id => 'ABCD1234' })
@@ -307,8 +307,8 @@ __END__
 
 =head2 is_archived
 
-	B<boolean>
-	Return only tenants that have been archived. Defaults to C<false>.
+B<boolean>
+Return only tenants that have been archived. Defaults to C<false>.
 
 	$tenants_export
 		->list_p({ is_archived => true })
@@ -323,8 +323,8 @@ __END__
 
 =head2 customer_id
 
-	B<string> C<<= 50 characters>
-	Lookup entities based on C<customer_id>.
+B<string> C<E<lt>= 50 characters>
+Lookup entities based on C<customer_id>.
 
 	$tenants_export
 		->list_p({ customer_id => 'ABC123' })
@@ -339,8 +339,8 @@ __END__
 
 =head2 customer_reference
 
-	B<string> C<<= 50 characters>
-	Customer reference of tenant.
+B<string> C<E<lt>= 50 characters>
+Customer reference of tenant.
 
 	$tenants_export
 		->list_p({ customer_reference => 'ABC123' })
@@ -355,22 +355,22 @@ __END__
 
 =head1 AUTHOR
 
-	Yanga Kandeni E<lt>yangak@cpan.orgE<gt>
+Yanga Kandeni E<lt>yangak@cpan.orgE<gt>
 
-	Valters Skrupskis E<lt>malishew@cpan.orgE<gt>
+Valters Skrupskis E<lt>malishew@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-	Copyright 2023- PayProp
+Copyright 2023- PayProp
 
 =head1 LICENSE
 
-	This library is free software; you can redistribute it and/or modify
-	it under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
-	If you would like to contribute documentation
-	or file a bug report then please raise an issue / pull request:
+If you would like to contribute documentation
+or file a bug report then please raise an issue / pull request:
 
-	L<https://github.com/Humanstate/api-client-public-module>
+L<https://github.com/Humanstate/api-client-public-module>
 
 =cut
